The *cd-repos.ps1* Script
===========================

This PowerShell script changes the working directory to the Git repositories folder.

Parameters
----------
```powershell
/Repos/PowerShell/scripts/cd-repos.ps1 [<CommonParameters>]

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./cd-repos.ps1
📂C:\Repos

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Sets the working directory to the Git repos folder
.DESCRIPTION
	This PowerShell script changes the working directory to the Git repositories folder.
.PARAMETER subpath
	Specifies an additional relative subpath (optional)
.EXAMPLE
	PS> ./cd-repos.ps1
	📂C:\Repos
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

try {
	if (Test-Path "~/Repos" -pathType Container) {		 # try short name in home dir
		$path = "~/Repos"
	} elseif (Test-Path "~/repos" -pathType Container) {
		$path = "~/repos"
	} elseif (Test-Path "~/Repositories" -pathType Container) { # try long name
		$path = "~/Repositories"
	} elseif (Test-Path "~/repositories" -pathType Container) {
		$path = "~/repositories"
	} elseif (Test-Path "/Repos" -pathType Container) { # try short name in root dir
		$path = "/Repos"
	} elseif (Test-Path "/repos" -pathType Container) {
		$path = "/repos"
	} elseif (Test-Path "/Repositories" -pathType Container) { # try long name
		$path = "/Repositories"
	} elseif (Test-Path "/repositories" -pathType Container) {
		$path = "/repositories"
	} elseif (Test-Path "~/source/repos" -pathType Container) { # try Visual Studio default
		$path = "~/source/repos"
	} else {
		throw "No Git repositories folder in your home directory or in the root folder yet"
	}
	$path = Resolve-Path $path
	Set-Location "$path"
	"📂$path"
	exit 0 # success
} catch {
	"⚠️ Error: $($Error[0])"
	exit 1
}
```

*(page generated by convert-ps2md.ps1 as of 01/23/2025 12:15:19)*
